You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@myfaces.apache.org by em...@apache.org on 2018/02/14 14:05:27 UTC

svn commit: r1824242 - /myfaces/core/branches/2.3.x/impl/src/main/java/org/apache/myfaces/config/FacesConfigurator.java

Author: embreijo
Date: Wed Feb 14 14:05:27 2018
New Revision: 1824242

URL: http://svn.apache.org/viewvc?rev=1824242&view=rev
Log:
MYFACES-4201 InstantiationException for ConfigurableNavigationHandler that does not have a default constructor

Modified:
    myfaces/core/branches/2.3.x/impl/src/main/java/org/apache/myfaces/config/FacesConfigurator.java

Modified: myfaces/core/branches/2.3.x/impl/src/main/java/org/apache/myfaces/config/FacesConfigurator.java
URL: http://svn.apache.org/viewvc/myfaces/core/branches/2.3.x/impl/src/main/java/org/apache/myfaces/config/FacesConfigurator.java?rev=1824242&r1=1824241&r2=1824242&view=diff
==============================================================================
--- myfaces/core/branches/2.3.x/impl/src/main/java/org/apache/myfaces/config/FacesConfigurator.java (original)
+++ myfaces/core/branches/2.3.x/impl/src/main/java/org/apache/myfaces/config/FacesConfigurator.java Wed Feb 14 14:05:27 2018
@@ -732,11 +732,13 @@ public class FacesConfigurator
         
         // First build the object
         NavigationHandler navigationHandler = ClassUtils.buildApplicationObject(NavigationHandler.class,
+                ConfigurableNavigationHandler.class, null,
                 dispenser.getNavigationHandlerIterator(),
                 application.getNavigationHandler());
         // Invoke inject and post construct
         _callInjectAndPostConstruct(navigationHandler);
         // Finally wrap the object with the BackwardsCompatibleNavigationHandlerWrapper
         navigationHandler = ClassUtils.wrapBackwardCompatible(NavigationHandler.class,
                 ConfigurableNavigationHandler.class,
                 BackwardsCompatibleNavigationHandlerWrapper.class,
@@ -732,11 +732,13 @@ public class FacesConfigurator
         // Invoke inject and post construct
         _callInjectAndPostConstruct(navigationHandler);
-        // Finally wrap the object with the BackwardsCompatibleNavigationHandlerWrapper
+        // Finally wrap the object with the BackwardsCompatibleNavigationHandlerWrapper if it is not assignable
+        // from ConfigurableNavigationHandler
         navigationHandler = ClassUtils.wrapBackwardCompatible(NavigationHandler.class,
                 ConfigurableNavigationHandler.class,